Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultGroup = &Group{
Dir: "pages",
LayoutsDir: "layouts",
}
Functions ¶
func SetPrecache ¶
func SetPrecache(precache bool)
SetPrecache enables precaching of templates for production usage. By default, precache is disabled to ease website development.
Types ¶
type Group ¶
type Group struct {
Dir string
LayoutsDir string
Funcs template.FuncMap
// contains filtered or unexported fields
}
TODO: Is there a reason to add mutexes for safe concurrency? Everything should be called at init, in the same function, but...hmm.
func (*Group) SetPrecache ¶
Click to show internal directories.
Click to hide internal directories.